@@ -155,7 +155,13 @@ def load_ecco_vars_from_mds(mds_var_dir,
     if model_time_steps_to_load == 'all':
         if not less_output:
             print ('loading all model time steps')
+            print('read bin_llc:')
+            print(mds_var_dir)
+            print(mds_grid_dir)
 
+        print('read bin_llc:')
+        print(mds_var_dir)
+        print(mds_grid_dir)
         ecco_dataset = open_mdsdataset(data_dir = mds_var_dir, 
                                        grid_dir = mds_grid_dir,
                                        read_grid = True,
@@ -166,7 +172,8 @@ def load_ecco_vars_from_mds(mds_var_dir,
                                        delta_t  = delta_t,
                                        default_dtype = np.dtype(mds_datatype),
                                        grid_vars_to_coords=True,
-                                       llc_method = llc_method)
+                                       llc_method = llc_method,
+                                       ignore_unknown_vars=True)
     
     else:
         if not less_output:
@@ -186,7 +193,8 @@ def load_ecco_vars_from_mds(mds_var_dir,
                                            delta_t = delta_t,
                                            default_dtype = np.dtype(mds_datatype),
                                            grid_vars_to_coords=True,
-                                           llc_method=llc_method)
+                                           llc_method=llc_method,
+                                           ignore_unknown_vars=True)
         else:
             raise TypeError('not a valid model_time_steps_to_load.  must be "all", an "int", or a list of "int"')
 
@@ -322,6 +330,9 @@ def load_ecco_vars_from_mds(mds_var_dir,
 
         # use the variable specific keys from the meta_variable_specific
         # dictionary
+        if not less_output:
+            print('added metadata to %s ' % ecco_var)
+            
         if ecco_var in meta_variable_specific.keys():
             ecco_dataset[ecco_var].attrs = meta_variable_specific[ecco_var]
 
@@ -483,7 +494,7 @@ def read_llc_to_tiles(fdir, fname, llc=90, skip=0, nk=1, nl=1,
         full_filename = '%s/%s' % (fdir,fname)
 
         if not less_output:
-            print('full_filename: ',full_filename)
+            print('read_llc_to_tiles: full_filename: ',full_filename)
         
         # Handle "skipped" records by reading up until that record, and
         # dropping preceding records afterward
@@ -530,9 +541,6 @@ def read_llc_to_tiles(fdir, fname, llc=90, skip=0, nk=1, nl=1,
 
         data_tiles   = llc_compact_to_tiles(data_compact, less_output=less_output)
 
-    if not less_output:
-        print('data_tiles shape = ',data_tiles.shape)
-        
     # return the array
     return data_tiles
 
